@@ -27,7 +27,11 @@
 
 class Exciter : public PluginBase {
  public:
-  Exciter(const std::string& tag, const std::string& schema, const std::string& schema_path, PipeManager* pipe_manager);
+  Exciter(const std::string& tag,
+          const std::string& schema,
+          const std::string& schema_path,
+          PipeManager* pipe_manager,
+          PipelineType pipe_type);
   Exciter(const Exciter&) = delete;
   auto operator=(const Exciter&) -> Exciter& = delete;
   Exciter(const Exciter&&) = delete;
