@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,7 +19,9 @@
 
 #pragma once
 
+#include <nlohmann/json_fwd.hpp>
 #include "plugin_preset_base.hpp"
+#include "preset_type.hpp"
 
 class LimiterPreset : public PluginPresetBase {
  public:
