@@ -40,7 +40,8 @@ class MultibandCompressor : public PluginBase {
   MultibandCompressor(const std::string& tag,
                       const std::string& schema,
                       const std::string& schema_path,
-                      PipeManager* pipe_manager);
+                      PipeManager* pipe_manager,
+                      PipelineType pipe_type);
   MultibandCompressor(const MultibandCompressor&) = delete;
   auto operator=(const MultibandCompressor&) -> MultibandCompressor& = delete;
   MultibandCompressor(const MultibandCompressor&&) = delete;
