@@ -121,31 +121,37 @@ void on_startup(GApplication* gapp) {
       return;
     }
 
-    util::debug("device " + device.name + " has changed its input route to: " + device.input_route_name);
+    util::debug("input autoloading: device " + device.name + " has changed its input route to \"" +
+                device.input_route_name + "\"");
 
-    NodeInfo target_node;
+    // Use a NodeInfo vector trying to fix #3180
+    std::vector<NodeInfo> target_node;
 
     for (const auto& [serial, node] : self->pm->node_map) {
       if (node.media_class == tags::pipewire::media_class::source) {
         if (util::str_contains(node.name, device.bus_path) || util::str_contains(node.name, device.bus_id)) {
-          target_node = node;
-
-          break;
+          target_node.push_back(node);
         }
       }
     }
 
-    if (target_node.id != SPA_ID_INVALID) {
-      auto name = util::gsettings_get_string(self->sie_settings, "input-device");
+    const auto name = util::gsettings_get_string(self->sie_settings, "input-device");
 
-      if (target_node.name == name) {
-        self->presets_manager->autoload(PresetType::input, target_node.name, device.input_route_name);
-      } else {
-        util::debug("input autoloading: the target node name does not match the input device name");
+    for (const auto& node : target_node) {
+      if (node.serial == SPA_ID_INVALID) {
+        continue;
+      }
+
+      if (node.name == name) {
+        util::debug("input autoloading: target node " + name + " matches the input device name");
+
+        self->presets_manager->autoload(PresetType::input, node.name, device.input_route_name);
+
+        return;
       }
-    } else {
-      util::debug("input autoloading: could not find the target node");
     }
+
+    util::debug("input autoloading: no target nodes match the input device name");
   }));
 
   self->data->connections.push_back(self->pm->device_output_route_changed.connect([=](const DeviceInfo device) {
@@ -153,31 +159,37 @@ void on_startup(GApplication* gapp) {
       return;
     }
 
-    util::debug("device " + device.name + " has changed its output route to: " + device.output_route_name);
+    util::debug("output autoloading: device " + device.name + " has changed its output route to \"" +
+                device.output_route_name + "\"");
 
-    NodeInfo target_node;
+    // Use a NodeInfo vector trying to fix #3180
+    std::vector<NodeInfo> target_node;
 
     for (const auto& [serial, node] : self->pm->node_map) {
       if (node.media_class == tags::pipewire::media_class::sink) {
         if (util::str_contains(node.name, device.bus_path) || util::str_contains(node.name, device.bus_id)) {
-          target_node = node;
-
-          break;
+          target_node.push_back(node);
         }
       }
     }
 
-    if (target_node.serial != SPA_ID_INVALID) {
-      auto name = util::gsettings_get_string(self->soe_settings, "output-device");
+    const auto name = util::gsettings_get_string(self->soe_settings, "output-device");
 
-      if (target_node.name == name) {
-        self->presets_manager->autoload(PresetType::output, target_node.name, device.output_route_name);
-      } else {
-        util::debug("output autoloading: the target node name does not match the output device name");
+    for (const auto& node : target_node) {
+      if (node.serial == SPA_ID_INVALID) {
+        continue;
+      }
+
+      if (node.name == name) {
+        util::debug("output autoloading: target node " + name + " matches the output device name");
+
+        self->presets_manager->autoload(PresetType::output, node.name, device.output_route_name);
+
+        return;
       }
-    } else {
-      util::debug("output autoloading: could not find the target node");
     }
+
+    util::debug("output autoloading: no target nodes match the output device name");
   }));
 
   self->data->gconnections_soe.push_back(g_signal_connect(
@@ -282,7 +294,7 @@ void application_class_init(ApplicationClass* klass) {
     if (g_variant_dict_contains(options, "presets") != 0) {
       std::string list;
 
-      for (const auto& name : self->presets_manager->get_names(PresetType::output)) {
+      for (const auto& name : self->presets_manager->get_local_presets_name(PresetType::output)) {
         list += name + ",";
       }
 
@@ -290,7 +302,7 @@ void application_class_init(ApplicationClass* klass) {
 
       list = "";
 
-      for (const auto& name : self->presets_manager->get_names(PresetType::input)) {
+      for (const auto& name : self->presets_manager->get_local_presets_name(PresetType::input)) {
         list += name + ",";
       }
 
@@ -337,21 +349,13 @@ void application_class_init(ApplicationClass* klass) {
 
       if (g_variant_dict_lookup(options, "load-preset", "&s", &name) != 0) {
         if (self->presets_manager->preset_file_exists(PresetType::input, name)) {
-          if (self->presets_manager->load_preset_file(PresetType::input, name)) {
-            g_settings_set_string(self->settings, "last-used-input-preset", name);
-          } else {
-            g_settings_reset(self->settings, "last-used-input-preset");
-          }
+          self->presets_manager->load_local_preset_file(PresetType::input, name);
 
           return EXIT_SUCCESS;
         }
 
         if (self->presets_manager->preset_file_exists(PresetType::output, name)) {
-          if (self->presets_manager->load_preset_file(PresetType::output, name)) {
-            g_settings_set_string(self->settings, "last-used-output-preset", name);
-          } else {
-            g_settings_reset(self->settings, "last-used-output-preset");
-          }
+          self->presets_manager->load_local_preset_file(PresetType::output, name);
 
           return EXIT_SUCCESS;
         }
