@@ -37,8 +37,15 @@
 AutoGain::AutoGain(const std::string& tag,
                    const std::string& schema,
                    const std::string& schema_path,
-                   PipeManager* pipe_manager)
-    : PluginBase(tag, tags::plugin_name::autogain, tags::plugin_package::ebur128, schema, schema_path, pipe_manager),
+                   PipeManager* pipe_manager,
+                   PipelineType pipe_type)
+    : PluginBase(tag,
+                 tags::plugin_name::autogain,
+                 tags::plugin_package::ebur128,
+                 schema,
+                 schema_path,
+                 pipe_manager,
+                 pipe_type),
       target(g_settings_get_double(settings, "target")),
       silence_threshold(g_settings_get_double(settings, "silence-threshold")) {
   reference = parse_reference_key(util::gsettings_get_string(settings, "reference"));
@@ -123,7 +130,7 @@ AutoGain::~AutoGain() {
 }
 
 auto AutoGain::init_ebur128() -> bool {
-  if (n_samples == 0 || rate == 0) {
+  if (n_samples == 0U || rate == 0U) {
     return false;
   }
 
