@@ -49,7 +49,7 @@ auto prepare_debug_message(const std::string& message, source_location location)
 
   std::ostringstream msg_stream;
 
-  msg_stream << "\t" << file_path.filename().string() << ":" << location.line() << "\t" << message;
+  msg_stream << "\t" << file_path.filename().string() << ":" << to_string(location.line()) << "\t" << message;
 
   return msg_stream.str();
 }
@@ -270,8 +270,6 @@ auto add_new_blocklist_entry(GSettings* settings, const std::string& name) -> bo
     return false;
   }
 
-  using namespace std::string_literals;
-
   auto list = util::gchar_array_to_vector(g_settings_get_strv(settings, "blocklist"));
 
   if (std::any_of(list.cbegin(), list.cend(), [&](const auto& str) { return str == name; })) {
@@ -290,8 +288,6 @@ auto add_new_blocklist_entry(GSettings* settings, const std::string& name) -> bo
 }
 
 void remove_blocklist_entry(GSettings* settings, const std::string& name) {
-  using namespace std::string_literals;
-
   auto list = util::gchar_array_to_vector(g_settings_get_strv(settings, "blocklist"));
 
   list.erase(std::remove_if(list.begin(), list.end(), [=](const auto& a) { return a == name; }), list.end());
@@ -405,6 +401,80 @@ auto str_contains(const std::string& haystack, const std::string& needle) -> boo
   return (haystack.find(needle) != std::string::npos);
 }
 
+void str_trim_start(std::string& str) {
+  // This util removes whitespaces such as simple space " ", new line "\n",
+  // carriage return "\r", tab "\t", vertical tab "\v" and form feed "\f"
+  // at the start of the given string.
+  // No copy involved, the input string is just modified if needed.
+
+  str.erase(0U, str.find_first_not_of(" \n\r\t\v\f"));
+}
+
+void str_trim_end(std::string& str) {
+  // Same as above, but at the end of the given string.
+  str.erase(str.find_last_not_of(" \n\r\t\v\f") + 1U);
+}
+void str_trim(std::string& str) {
+  // Trim both sides of the given string. See above.
+  str_trim_end(str);
+  str_trim_start(str);
+}
+
+auto search_filename(const std::filesystem::path& path,
+                     const std::string& filename,
+                     std::string& full_path_result,
+                     const uint& top_scan_level) -> bool {
+  // Recursive util to search a filename from an origin full path directory.
+  // The search is performed in subdirectories and it's stopped at a specified
+  // sublevel (top_scan_level = 1 searches only in the path).
+
+  if (!std::filesystem::exists(path) || !std::filesystem::is_directory(path)) {
+    return false;
+  }
+
+  const auto fn = path / filename;
+
+  // Get the file in this directory, if exists.
+  if (std::filesystem::exists(fn) && std::filesystem::is_regular_file(fn)) {
+    // File found, abort the search.
+    full_path_result = fn.c_str();
+
+    return true;
+  }
+
+  // The file is not in this directory, search in subdirectories.
+  const auto scan_level = top_scan_level - 1U;
+
+  if (scan_level == 0U) {
+    return false;
+  }
+
+  auto it = std::filesystem::directory_iterator{path};
+
+  try {
+    while (it != std::filesystem::directory_iterator{}) {
+      if (std::filesystem::is_directory(it->status())) {
+        if (const auto p = it->path(); !p.empty()) {
+          // Continue the search in the subfolder.
+          const auto found = search_filename(p, filename, full_path_result, scan_level);
+
+          if (found) {
+            return true;
+          }
+        }
+      }
+
+      ++it;
+    }
+  } catch (const std::exception& e) {
+    util::warning(e.what());
+
+    return false;
+  }
+
+  return false;
+}
+
 auto compare_versions(const std::string& v0, const std::string& v1) -> int {
   /* This is an util to compare two strings as semver, mainly used to compare
      two Pipewire versions.
